summaryrefslogtreecommitdiffstats
path: root/kicker/applets/launcher
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/applets/launcher')
-rw-r--r--kicker/applets/launcher/configdlgbase.ui16
-rw-r--r--kicker/applets/launcher/flowgridmanager.h4
-rw-r--r--kicker/applets/launcher/popularity.cpp2
-rw-r--r--kicker/applets/launcher/quickaddappsmenu.cpp2
-rw-r--r--kicker/applets/launcher/quickbutton.cpp2
-rw-r--r--kicker/applets/launcher/quicklauncher.cpp22
-rw-r--r--kicker/applets/launcher/quicklauncher.h2
7 files changed, 25 insertions, 25 deletions
diff --git a/kicker/applets/launcher/configdlgbase.ui b/kicker/applets/launcher/configdlgbase.ui
index bfb1bc4e6..7a2ded479 100644
--- a/kicker/applets/launcher/configdlgbase.ui
+++ b/kicker/applets/launcher/configdlgbase.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>ConfigDlgBase</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -75,7 +75,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>332</width>
<height>20</height>
@@ -97,7 +97,7 @@
</property>
<widget class="QLayoutWidget" row="3" column="0" rowspan="1" colspan="3">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<grid>
<property name="name">
@@ -130,7 +130,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>140</width>
<height>20</height>
@@ -144,7 +144,7 @@
<property name="text">
<string>Short Term</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignCenter</set>
</property>
</widget>
@@ -155,7 +155,7 @@
<property name="text">
<string>Long Term</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignCenter</set>
</property>
</widget>
@@ -184,7 +184,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>50</width>
<height>20</height>
@@ -265,7 +265,7 @@
<slot>setEnabled(bool)</slot>
</connection>
</connections>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kicker/applets/launcher/flowgridmanager.h b/kicker/applets/launcher/flowgridmanager.h
index 521490c51..5aaa814bb 100644
--- a/kicker/applets/launcher/flowgridmanager.h
+++ b/kicker/applets/launcher/flowgridmanager.h
@@ -13,8 +13,8 @@
class FlowGridManager {
-// Determine if two FlowGridManager objs have the same layout. They may or
-// may not have the same input parameters, but the resulting layout is identical.
+// Determine if two FlowGridManager objs have the same tqlayout. They may or
+// may not have the same input parameters, but the resulting tqlayout is identical.
friend bool operator== ( const FlowGridManager & gp1, const FlowGridManager & gp2 );
public:
diff --git a/kicker/applets/launcher/popularity.cpp b/kicker/applets/launcher/popularity.cpp
index a22a98c99..e446a2ec7 100644
--- a/kicker/applets/launcher/popularity.cpp
+++ b/kicker/applets/launcher/popularity.cpp
@@ -182,7 +182,7 @@ void PopularityStatistics::moveToTop(const TQStringList& newTopServiceList)
//kdDebug() << "->Re-Added service " <<
//ranking[serviceIndex].popularity
// << " " << *servIt << endl;
- //kdDebug() << "...was replaced by " << *servIt << endl;
+ //kdDebug() << "...was tqreplaced by " << *servIt << endl;
}
else
{
diff --git a/kicker/applets/launcher/quickaddappsmenu.cpp b/kicker/applets/launcher/quickaddappsmenu.cpp
index 0eebec315..7dcb16098 100644
--- a/kicker/applets/launcher/quickaddappsmenu.cpp
+++ b/kicker/applets/launcher/quickaddappsmenu.cpp
@@ -53,7 +53,7 @@ QuickAddAppsMenu::QuickAddAppsMenu(TQWidget *target, TQWidget *parent, const TQS
void QuickAddAppsMenu::slotExec(int id)
{
- if (!entryMap_.contains(id)) return;
+ if (!entryMap_.tqcontains(id)) return;
KSycocaEntry * e = entryMap_[id];
KService::Ptr service = static_cast<KService *>(e);
emit addAppBefore(locate("apps", service->desktopEntryPath()),_sender);
diff --git a/kicker/applets/launcher/quickbutton.cpp b/kicker/applets/launcher/quickbutton.cpp
index 2ac0742ca..d002b56ce 100644
--- a/kicker/applets/launcher/quickbutton.cpp
+++ b/kicker/applets/launcher/quickbutton.cpp
@@ -140,7 +140,7 @@ QuickButton::QuickButton(const TQString &u, KAction* configAction,
TQToolTip::add(this, _qurl->name());
resize(int(DEFAULT_ICON_DIM),int(DEFAULT_ICON_DIM));
- TQBrush bgbrush(colorGroup().brush(TQColorGroup::Background));
+ TQBrush bgbrush(tqcolorGroup().brush(TQColorGroup::Background));
QuickAddAppsMenu *addAppsMenu = new QuickAddAppsMenu(
parent, this, _qurl->url());
diff --git a/kicker/applets/launcher/quicklauncher.h b/kicker/applets/launcher/quicklauncher.h
index 2dadf6344..709904858 100644
--- a/kicker/applets/launcher/quicklauncher.h
+++ b/kicker/applets/launcher/quicklauncher.h
@@ -111,7 +111,7 @@ protected slots:
void slotStickyToggled();
protected:
- void updateInsertionPosToStatusQuo();
+ void updateInsertionPosTotqStatusQuo();
void updateStickyHighlightLayer();
QuickButton* createButton(TQString url);
virtual void paintEvent(TQPaintEvent* e);
diff --git a/kicker/applets/launcher/quicklauncher.cpp b/kicker/applets/launcher/quicklauncher.cpp
index a278b39c9..6b56032aa 100644
--- a/kicker/applets/launcher/quicklauncher.cpp
+++ b/kicker/applets/launcher/quicklauncher.cpp
@@ -438,11 +438,11 @@ void QuickLauncher::addApp(TQString url, int index, bool manuallyAdded)
}
}
- updateInsertionPosToStatusQuo();
+ updateInsertionPosTotqStatusQuo();
saveConfig();
}
-void QuickLauncher::updateInsertionPosToStatusQuo()
+void QuickLauncher::updateInsertionPosTotqStatusQuo()
{
// Update the app ordering map, so that next time,
// addApp(url,manAdded) (without index) will insert the
@@ -633,7 +633,7 @@ void QuickLauncher::dropEvent(TQDropEvent *e)
clearTempButtons();
refreshContents();
saveConfig();
- updateInsertionPosToStatusQuo();
+ updateInsertionPosTotqStatusQuo();
}
// insert dragbuttons at index in m_newButtons. Put result in m_buttons
@@ -828,7 +828,7 @@ void QuickLauncher::loadConfig()
for (n=0; n<int(m_buttons->size()); ++n)
{
QuickButton* button = (*m_buttons)[n];
- if (volatileButtons.contains(button->menuId()) == false)
+ if (volatileButtons.tqcontains(button->menuId()) == false)
{
button->setSticky(true);
}
@@ -912,7 +912,7 @@ void QuickLauncher::serviceStartedByStorageId(TQString /*starter*/, TQString sto
QuickURL url = QuickURL(locate("apps", service->desktopEntryPath()));
TQString desktopMenuId(url.menuId());
kdDebug() << "storageId=" << storageId << " desktopURL=" << desktopMenuId << endl;
// A service was started somwhere else. If the quicklauncher contains
// this service too, we flash the icon
QuickButton *startedButton = 0;
std::set<TQString> buttonIdSet;
@@ -1040,19 +1040,19 @@ void QuickLauncher::updateStickyHighlightLayer()
m_stickyHighlightLayer = TQImage(width(), height(), 32);
m_stickyHighlightLayer.setAlphaBuffer(true);
int pix, tlPix, brPix, w(width()), h(height());
- QRgb transparent(qRgba(0, 0, 0, 0));
+ QRgb transparent(tqRgba(0, 0, 0, 0));
for (int y = h-1; y >= 0; --y)
{
for (int x = w-1; x >= 0; --x)
{
- pix = qRed(areaLayer.pixel(x, y));
+ pix = tqRed(areaLayer.pixel(x, y));
if (pix == 0)
{
- tlPix = (y>0 && x>0) ? qRed(areaLayer.pixel(x-1,y-1)) : 255;
- brPix = (y<h-1 && x<w-1) ? qRed(areaLayer.pixel(x+1,y+1)) : 255;
+ tlPix = (y>0 && x>0) ? tqRed(areaLayer.pixel(x-1,y-1)) : 255;
+ brPix = (y<h-1 && x<w-1) ? tqRed(areaLayer.pixel(x+1,y+1)) : 255;
int c = tlPix-brPix < 0 ? 255 : 0;
int alpha = abs(tlPix-brPix)/2;
- m_stickyHighlightLayer.setPixel(x, y, qRgba(c, c, c, alpha));
+ m_stickyHighlightLayer.setPixel(x, y, tqRgba(c, c, c, alpha));
}
else
{
@@ -1060,7 +1060,7 @@ void QuickLauncher::updateStickyHighlightLayer()
}
}
}
- repaint();
+ tqrepaint();
}
void QuickLauncher::paintEvent(TQPaintEvent* e)
@@ -912,7 +912,7 @@ void QuickLauncher::serviceStartedByStorageId(TQString /*starter*/, TQString sto
TQString desktopMenuId(url.menuId());
kdDebug() << "storageId=" << storageId << " desktopURL=" << desktopMenuId << endl;
- // A service was started somwhere else. If the quicklauncher contains
+ // A service was started somwhere else. If the quicklauncher tqcontains
// this service too, we flash the icon
QuickButton *startedButton = 0;